//for water transparency modification

uniform sampler2D colorMap;
uniform float water_transparency;
uniform float waterfall_transparency;
uniform vec3 waterfall_color;
uniform float setting_v3;
varying vec4 texcoord;
varying vec4 vert_color;
varying float is_vertical;
varying float fogFactor;

//0.1666
//float water_transparency = 0.1; //.2, 0.12
//float waterfall_transparency = 0.25; //.2

void main()
{
    //waterfall_color = vec3(0.1, 0.6, 0.3);
    vec4 color = texture2D(colorMap,texcoord.rg);
    vec4 out_color = vec4(1.0);
    float alpha = color.a;
    
    if (is_vertical <= 0.1) { //required to render ice properly
        //-1 at surface
        //0 at waterfall
        alpha = ((-is_vertical) * water_transparency) + (1.0+is_vertical) * waterfall_transparency;
        
        if (setting_v3 >= 1.0) {
            //v3b settings
            color.rgb = (2.0*color.r + 2.0*color.g + 2.0*color.b)/4.5 + color.rgb*0.8;
        }
        
        vec4 col = vec4(vert_color.r*color.r, vert_color.g*color.g, vert_color.b*color.b, alpha);
        out_color = (-is_vertical) * col + (1.0+is_vertical) * col * vec4(waterfall_color, 1.0);
        
    } else {
        out_color = vec4(vert_color.r*color.r, vert_color.g*color.g, vert_color.b*color.b, alpha);
    }
    
    if (is_vertical > -0.9) {
        gl_FragColor = mix(gl_Fog.color, out_color, fogFactor);
    } else {    
        gl_FragColor = out_color;
    }
    
    gl_FragColor = out_color;
	
}